# Here you can create samples of your widgets by providing default parameters,
# inserting them in a container widget, mixing them with other widgets, etc...
# These samples will appear in the (unimplemented yet) widget browser.
