# Metadata for the widget EGG. Should leave it for the (unimplemented) widget
# tracker to track it

__PROJECT__ = 'tw.recaptcha'
__DESCRIPTION__ = 'Handy ReCaptcha Toscawidget'
__URL__ = 'http://toscawidgets.org/'
__VERSION__ = '0.8'
__AUTHOR__ = 'Christopher Perkins'
__EMAIL__ = 'chris@percious.com'
__COPYRIGHT__ = "Copyright 2008 Christopher Perkins"
__LICENSE__ = 'MIT'
